@@ -44,8 +44,8 @@ __BEGIN_DECLS
  */
 int gsl_sf_coupling_3j_e(int two_ja, int two_jb, int two_jc,
                             int two_ma, int two_mb, int two_mc,
-			    gsl_sf_result * result
-			    );
+                            gsl_sf_result * result
+                            );
 double gsl_sf_coupling_3j(int two_ja, int two_jb, int two_jc,
                           int two_ma, int two_mb, int two_mc
                           );
@@ -64,7 +64,6 @@ double gsl_sf_coupling_6j(int two_ja, int two_jb, int two_jc,
                           int two_jd, int two_je, int two_jf
                           );
 
-
 /* Racah W coefficients:
  *
  *   W(a b c d; e f) = (-1)^{a+b+c+d} / a b e \
@@ -115,7 +114,7 @@ int gsl_sf_coupling_6j_INCORRECT_e(int two_ja, int two_jb, int two_jc,
                                    int two_jd, int two_je, int two_jf,
                                    gsl_sf_result * result
                                    );
-double gsl_sf_coupling_INCORRECT_6j(int two_ja, int two_jb, int two_jc,
+double gsl_sf_coupling_6j_INCORRECT(int two_ja, int two_jb, int two_jc,
                                     int two_jd, int two_je, int two_jf
                                     );
 #endif /* !GSL_DISABLE_DEPRECATED */
